@@ -1,23 +1,19 @@
-use clap::{ArgEnum, Parser};
+use clap::Parser;
 use std::path::PathBuf;
 
 /// Assistant Bot for Programmers
 #[derive(Parser)]
-#[clap(author, version, about, trailing_var_arg = true)]
+#[clap(version, trailing_var_arg = true)]
 pub struct Args {
     /// Request query
     #[clap(multiple_occurrences(true))]
     pub query: Vec<String>,
 
-    /// Specify the output format
-    #[clap(arg_enum, short, long, default_value_t = Mode::Auto)]
-    pub mode: Mode,
-
     /// Increase the logging verbosity
     #[clap(short, long, parse(from_occurrences))]
     pub verbose: usize,
 
-    /// Show the inferred result instead of running it
+    /// Show the inferred internal command without running it
     #[clap(long)]
     pub dry_run: bool,
 
@@ -25,7 +21,7 @@ pub struct Args {
     #[clap(short, long)]
     pub run: bool,
 
-    /// Input files
+    /// Specify input files
     #[clap(short, long, multiple_occurrences(true))]
     pub input: Vec<PathBuf>,
 
@@ -34,13 +30,6 @@ pub struct Args {
     pub config: Option<PathBuf>,
 
     /// Dump embedded model data.
-    #[clap(long, display_order(1002))]
+    #[clap(long, hide(true), display_order(1002))]
     pub dump_model: Option<PathBuf>,
 }
-
-#[derive(ArgEnum, Clone, PartialEq, Eq)]
-pub enum Mode {
-    Auto,
-    Direct,
-    Repl,
-}
